function M = animWalk7(rowPath, colPath, foodGrids)
% ANIMWALK - Animation of toads, food, AWPs, and moist areas
% The image of the food grid is changed, up-to-down, to match display of matrices.
% Thus, food location with row 1 and column 1 displays at top left corner, 
% as it does in numeric display of the corresponding matrix.  
% For a toad's, AWP's, moist area's, and fence's locations, matrix row and 
% column corresponding to grids, such as moisture and food, are used.  
% For example, to display a toad in the correct corresponding location, its
% x coordinate is the column; while its y coordinate is SIDE + 1 - row.
% A food value of 1, indicating the maximum amount of food in a cell, 
% displays as black; while a food value of 0 displays as white.

clf;
global SIDE NUM_STEPS FOOD_CELL;
global ROWLST_AWP COLLST_AWP ROWLST_MOISTAREA COLLST_MOISTAREA;

M = moviein(NUM_STEPS);
vidObj = VideoWriter('caneToads.avi');  % save animation in video file
open(vidObj);

minRow = 1;
maxRow = SIDE;
minCol = 1;
maxCol = SIDE;

numToads = length(rowPath);

% longest path
pathLng = cellfun(@length, rowPath);

maxFoodValue = max(max(foodGrids{1}));
maxColorIndex = round(maxFoodValue * 10000) + 1;
for i = 1:maxColorIndex
    amt = (i - 1)/(maxColorIndex - 1);
    map(i, :) = [amt, amt, amt];
end; 
% foodDisplay = maxFoodValue * ones(SIDE);
% foodDisplay = (maxFoodValue)*ones(SIDE);
foodDisplay = zeros(SIDE);
% maxLng = max(pathLng);
maxLng = NUM_STEPS + 1;
for i = 1:maxLng
    hold on;
    % flip matrix up-to-down so that image matches matrix display
    foodDisplay(2:SIDE-1, 2:SIDE-1) = foodGrids{i}(2:SIDE-1, 2:SIDE-1);
    % use the following command to make initial background gray
    foodDisplay(ROWLST_AWP(1), COLLST_AWP(1)) = (maxFoodValue+0.1);
    imagesc(flipud(maxFoodValue - foodDisplay));
    colormap(map);

    plot(COLLST_AWP, SIDE + 1 - ROWLST_AWP, 's',  'MarkerFaceColor', 'b', 'MarkerEdgeColor','b', 'MarkerSize', 300/SIDE)
    plotFences(COLLST_AWP, ROWLST_AWP);
    plot(COLLST_MOISTAREA, SIDE + 1 - ROWLST_MOISTAREA, 's',  'MarkerFaceColor', [0.7 0.5 0], ...
        'MarkerEdgeColor', [0.7 0.5 0], 'MarkerSize', 300/SIDE)
    for k = 1:numToads
        if colPath{k}(i) > 1 % still alive
            if i <= pathLng(k) 
% % % offset each toad a little to show multiple toads in a cell
                plot(colPath{k}(i) + 0.25*rand - 0.25, SIDE + 1 - rowPath{k}(i) + 0.25*rand - 0.25, 'ok', 'MarkerFaceColor', 'g', 'MarkerSize', 100/SIDE);
            else 
                plot(colPath{k}(pathLng(k)), SIDE + 1 - rowPath{k}(pathLng(k)),  'ok', 'MarkerFaceColor', 'g', 'MarkerSize', 100/SIDE);
            end;
        end;
    end;
    axis([minRow maxRow minCol maxCol]);
    axis equal;
    axis off;
    drawnow;
    M(i) = getframe;
    writeVideo(vidObj,M(i));
    
    %  white out last step
    if i < maxLng
        for k = 1:numToads
            if rowPath{k}(i) > 1 % still alive
                if i <= pathLng(k) 
                    plot(colPath{k}(i), SIDE + 1 - rowPath{k}(i), 'ow', 'MarkerFaceColor', [1,1,1], 'MarkerSize', 100/SIDE);
                else
                    plot(colPath{k}(pathLng(k)), SIDE + 1 - rowPath{k}(pathLng(k)), 'ow', 'MarkerFaceColor', [1,1,1], 'MarkerSize', 100/SIDE);
                end;
            end
        end
    end
end;  

close(vidObj);
