function matLst = getNbrsLst(aToad, numNeighbors, elimPrevious )
%GETNNBRSLST gets row and column coordinates of toad's neighbors
%   matLst = getNbrsLst( aToad, numNeighbors, elimPrevious ) returns row
%   and column  coordinates of toad's neighbors for numNeighbors == 4, 5, 8, or 9.
%   Results are returned in a matrix with the first column being row
%   coordinates and the second column being column coordinates of the
%   neighbors.  If elimPrevious is true, the previous location is
%   eliminated.  Fenced AWPs are not included as neighbors.  Areas on the grid 
%   boundary to the north, east, and south are not included as neighbors.
%   If numNeighbors is 4 or 5, von Neuman neighborhood is used.
%   If numNeighbors is 8 or 9, Moore neighborhood is used.
%   If numNeighbors == 5 or 9, the toad's current location is included.

global SIDE ROWLST_AWP COLLST_AWP FENCED;

% get row and column coordinates of all neighbors 
if numNeighbors == 4
    rowLst = [              aToad.row - 1; aToad.row;      aToad.row + 1; aToad.row];
    colLst =  [              aToad.col;        aToad.col + 1; aToad.col;        aToad.col - 1];
elseif numNeighbors == 5
    rowLst = [aToad.row; aToad.row - 1; aToad.row;      aToad.row + 1; aToad.row];
    colLst =  [aToad.col;  aToad.col;        aToad.col + 1; aToad.col;        aToad.col - 1];
elseif numNeighbors == 8
    rowLst = [              aToad.row - 1; aToad.row - 1; aToad.row;      aToad.row + 1;...
        aToad.row + 1;      aToad.row + 1; aToad.row;     aToad.row - 1; ];
    colLst =  [              aToad.col;        aToad.col + 1; aToad.col + 1; aToad.col + 1;...
        aToad.col;             aToad.col - 1;   aToad.col - 1; aToad.col - 1];
elseif numNeighbors == 9
    rowLst = [aToad.row; aToad.row - 1; aToad.row - 1; aToad.row;      aToad.row + 1;...
        aToad.row + 1;      aToad.row + 1; aToad.row;     aToad.row - 1 ];
    colLst =  [aToad.col;  aToad.col;        aToad.col + 1; aToad.col + 1; aToad.col + 1;...
        aToad.col;             aToad.col - 1;   aToad.col - 1; aToad.col - 1];
end


% eliminate fenced AWPs  
if length(FENCED) > 0
    matLst = setdiff([rowLst colLst], [ROWLST_AWP(FENCED)' COLLST_AWP(FENCED)'], 'rows');
    rowLst = matLst(:, 1);
    colLst = matLst(:, 2);
end

% indices to keep; eliminate certain boundaries
% Uncomment first 'keep' command for eliminating all boundaries
% Uncomment second 'keep' command for allowing toad to go off the grid to the
% west but not allowing the toad to go off the grid to the north, east, or south
% keep = (rowLst ~= 1) & (rowLst ~= SIDE) & (colLst ~= 1) & (colLst ~= SIDE);
keep = (rowLst ~= 1) & (rowLst ~= SIDE) & (colLst ~= SIDE);
rowLst = rowLst(keep);
colLst = colLst(keep);

% if elimPrevious, eliminate last location where toad was
if elimPrevious  
    matLst = setdiff([rowLst colLst], [aToad.rowLast aToad.colLast], 'rows'); 
else
    matLst = [rowLst colLst];
end

end

