function [row col] = hopToMax(rowLst, colLst, gridMat)
%HOPTOMAX row and column of new toad location with maximum grid value
%   [row col] = hopToMax(rowLst, colLst, gridMat) returns the row and
%   column of the new toad position from the list of possibilities in
%   rowLst, colLst.  The new position has the maximum gridMat value,
%   selected at random in case of ties.

% find grid levels of neighbors
valuesAround = zeros(1, length(rowLst));
for i = 1:length(rowLst)
    valuesAround(i) = gridMat(rowLst(i), colLst(i));
end

% Find direction of maximum value
% If more than 1 location, pick at random
dirLst = valuesAround == max(valuesAround);
if sum(dirLst) > 1 % maximum moisture in more than 1 direction
    newDirLst = randperm(length(dirLst)).*dirLst;
    dirLst= newDirLst == max(newDirLst);
end;

row = rowLst(dirLst);
col = colLst(dirLst);

end

