function [  ] = init(  )
%INIT Initialize system
%   init() initializes food & moisture grids, toads, and constants
% % % To restrict toads from leaving the grid or to allow toads to migrate
% to the west, adjust the assignments to 'keep' in 'getNbrsLst.m', first
% column of 'moisture' in 'initMoisture.m', and first column of 'food in
% 'initFood.m'

global toads food FENCED moisture;
global LIMITED MOIST_AREA AWP AWP_R1 AWP_R2 NATURAL_WATER;
global ROWLST_AWP COLLST_AWP ROWLST_MOISTAREA COLLST_MOISTAREA;
global FOOD_CELL MEAN_FOOD STD_FOOD;
global SIDE NUM_STEPS NUM_NEIGHBORS;
global MEAN_WATER STD_WATER MEAN_ENERGY STD_ENERGY;
global NUM_TOADS MAY_HOP MAY_EAT;
global WATER_HOPPING ENERGY_HOPPING AMT_DRINK;
global WOULD_LIKE_DRINK NEED_TO_DRINK;
global WOULD_LIKE_EAT AMT_EAT FRACTION_WATER;
global DESICCATE STARVE ALIVE DEAD MIGRATED;

NUM_STEPS = 300; % number of simulation steps
SIDE = 20; % number of cells along 1 side of grid
NUM_NEIGHBORS = 8; % 4 (von Neumann) or 8 (Moore) = number of 
                                 % neighbors not including self

% toad constants
NUM_TOADS = 50; % number of toads
MEAN_WATER = 0.94; % mean water for initialized toad
STD_WATER = 0.02; % standard deviation water for initialized toad
MEAN_ENERGY = 0.94; % mean energy for initialized toad
STD_ENERGY = 0.02; % standard deviation energy for initialized toad
MAY_HOP = 0.5;  % probability of hopping if not thirsty or hungry
MAY_EAT = 0.2;  % probability of eating if thirsty
WATER_HOPPING = 0.002; % amount water used by toad in a hop
ENERGY_HOPPING = 0.002; % amount energy used by toad in a hop
WOULD_LIKE_DRINK = 0.9;  % water level at which toad would like to drink
NEED_TO_DRINK = 0.8; % water level at which toad really needs to drink
AMT_DRINK = 0.05; % amount toad drinks from water source in 1 time step
WOULD_LIKE_EAT = 0.9;  % food level at which toad would like to eat
AMT_EAT = 0.01; % max amount toad eats from food cell source in 1 time step
FRACTION_WATER = 0.6; % fraction of prey that is water
DESICCATE = 0.6; % level at which desiccation occurs
STARVE = 0.6; % level at which starvation occurs
ALIVE = 1;
DEAD = 0;
MIGRATED = 2;

% constants for moisture grid
LIMITED = 0.0;
MOIST_AREA = 0.5;
AWP = 1.0;
AWP_R1 = 0.4;
AWP_R2 = 0.2;
NATURAL_WATER = 1;

% constants for food grid
MEAN_FOOD = 0.1;
STD_FOOD = 0.02;
FOOD_CELL = 0.03;
% FOOD_CELL = 1.00;

food = initFood();
toads = initToads( );

% initialize moist areas
ROWLST_MOISTAREA = [floor(0.7 * SIDE) floor(0.8 * SIDE) floor(0.2 * SIDE)];
COLLST_MOISTAREA = [floor(0.4 * SIDE) floor(0.8 * SIDE) floor(0.9 * SIDE)];
% ROWLST_MOISTAREA = [];
% COLLST_MOISTAREA = [];

% initialize AWPs
% ROWLST_AWP = [floor(0.8 * SIDE) floor(0.6 * SIDE) floor(0.2 * SIDE)];  % 8 6 2
% COLLST_AWP = [floor(0.8 * SIDE) floor(0.3 * SIDE) floor(0.5 * SIDE)];  % 8 3 5
ROWLST_AWP = [floor(0.2 * SIDE) floor(0.6 * SIDE) floor(0.8 * SIDE) floor(0.5 * SIDE)];  % 
COLLST_AWP =  [floor(0.3 * SIDE) floor(0.7 * SIDE) floor(0.2 * SIDE) floor(0.5 * SIDE)];  % 
% ROWLST_AWP = [floor(0.5 * SIDE) ];
% COLLST_AWP = [floor(0.5 * SIDE)];

% vector of ROWLST_AWP (or COLLST_AWP) indices of fenced AWPs.
% % Use first line if no fencing, second if every AWP is fenced, variation of
% % third if some but not all fenced
FENCED = [];
% FENCED = 1:length(ROWLST_AWP);
% FENCED = [1];

moisture = initMoisture();

end

